previousPageSemanticLabel property
Semantic label for button to go to the previous page.
defaults to Previous Day/Month/Year according to picker type.
Implementation
final String? previousPageSemanticLabel;
Semantic label for button to go to the previous page.
defaults to Previous Day/Month/Year according to picker type.
final String? previousPageSemanticLabel;