selectedCellsDecoration property
The cell decoration of selected cells within the range.
defaults to circle with ColorScheme.primaryContainer color.
Implementation
final BoxDecoration? selectedCellsDecoration;
The cell decoration of selected cells within the range.
defaults to circle with ColorScheme.primaryContainer color.
final BoxDecoration? selectedCellsDecoration;